// Package net is a drop-in replacement to Golang's net package, with some more functionalities.
package net // import "github.com/xtls/xray-core/common/net"

//go:generate go run github.com/xtls/xray-core/common/errors/errorgen
